DNOTICIAS.PT

Funchal, 17° C

último comentário
100000000,00€ : 270000 madeirenses = 370...
por Edite Estrelada

#

" A melhor maneira de manter a fome de vencer é ficar em segundo"
Kelly Slater Surfista Ao i

## Manoel de Oliveira recebeu Legião de Honra francesa por "carreira fora do comum"

01:12 | 5 Sentidos
O realizador Manoel de Oliveira foi ontem distinguido com a Legião de Honra francesa,...

## Real Madrid volta a vencer todos os jogos e faz história na "Champions"

23:18 | Desporto | O Real Madrid tornou-se hoje a primeira equipa a vencer por duas vezes todos os jogos da fase...

## Leonardo Jardim estreia-se com passagem aos oitavos-de-final

Ontem, 21:55 | Desporto | Benfica disse adeus à Europa e Zenit de Danny ruma à Liga Europa

## Ricciardi acusa Ricardo Salgado de "infâmia"

Ontem, 21:04 | Economia | O presidente do Banco Espirito Santo de Investimento, José Maria Ricciardi, acusou...

## Por ano haverá um novo volume sobre a História da Madeira da autoria de Rui Carita

Ontem, 19:35 | 5 Sentidos | O primeiro, sobre o século XV, foi oficialmente lançado hoje no Colégio dos Jesuítas. Ao todo serão seis volumes, editados pela Imprensa Académica

Multimédia

- Vídeo
- Foto-reportagem

Ontem, 16:21

### Estão de volta ao cinema os dinossauros do Parque Jurássico

Veja o trailer do novo filme 'Jurassic World' que estreia em Junho de 2015. Steven Spielberg regressa como produtor executivo
Ontem, 16:11

### 30 fotos do dérbi que opôs Nacional e Marítimo

O jogo de segunda-feira terminou com uma vitória dos alvinegros por três bolas a zero

## Laurent Blanc propõe uma Bola de Ouro para Ronaldo e outra para Messi

Ontem, 19:11 | Desporto | O treinador do Paris Saint-Germain sugeriu hoje que o português Cristiano Ronaldo e o argentino... 2 comentários

## Francisco Lufinha ligou Selvagens à Madeira em 12 horas

Ontem, 18:37 | Desporto | Velejador português chegou há pouco ao Funchal 2 comentários

## Francisco Lufinha a 19 milhas do Funchal

Ontem, 17:18 | Desporto | Velejador tem agora pela frente um forte trabalho com o vento

## O "melhor orçamento" porque é o último

Ontem, 17:03 | Política | A sessão de abertura do debate do Plano e Orçamento para 2015 terminou com as intervenções... 2 comentários

## PTP acusa a maioria de proteger a "nomenclatura do regime"

Ontem, 16:56 | Política | Raquel Coelho (PTP) considera que este orçamento "é uma proposta a prazo",... 2 comentários

## TAP confirma suspensão da rota Funchal/Londres Funchal

Ontem, 16:48 | Economia | O presidente executivo da TAP confirmou hoje a notícia avançada pelo... 6 comentários

## Processo contra Alberto João Jardim com alegações finais a 19 de Dezembro

Ontem, 16:16 | Madeira | O Tribunal de Instância Local do Funchal agendou, hoje, para dia o 19 de dezembro as alegações... 2 comentários

## Francisco Lufinha perto das Ilhas Desertas

Ontem, 15:32 | Desporto | Velejador português deve chegar ao Funchal entre as 17 e 18 horas

## Madeira é a região onde mais se morre por doenças respiratórias

Ontem, 15:16 | Madeira | Mortalidade por estas patologias corresponde a 18,5% da totalidade dos óbitos 4 comentários

## Chegada prevista entre as 16 e as 17 horas

Ontem, 14:51 | Desporto | Velejador Francisco Lufinha terá recepção da MINI Madeira

## Cavaco contesta que tenha influenciado compra de acções do BES

23:19 | País | O Presidente da República contestou hoje que tenha influenciado, com afirmações...

## Sorteio de sexta-feira do Euromilhões com 'jackpot' de 31 milhões de euros

23:15 | País | O próximo sorteio do Euromilhões, na sexta-feira, terá um 'jackpot' de 31 milhões...

## União e APD-M apresentaram projecto com o circo Luna Park

Ontem, 22:23 | Desporto | Sócios da APD-M podem assistir aos jogos do União sem custos

## Altice assina acordo definitivo com Oi para comprar PT Portugal

Ontem, 21:06 | Economia | O grupo francês Altice assinou hoje um acordo definitivo com a operadora brasileira...

## Madeira SAD defronta Sporting na Taça de Portugal

Ontem, 20:03 | Desporto | O Sporting, detentor da Taça de Portugal de andebol, vai receber o Madeira SAD nos 16 avos...

## Pilotos da Portugália admitem fazer greve contra privatização do grupo TAP

Ontem, 19:30 | País | Os pilotos da Portugália (PGA) vão analisar, na quinta-feira, o processo negocial...

## Posto da GNR de Castanheira do Ribatejo com infiltrações de água e baratas

Ontem, 17:58 | País | A Associação dos Profissionais da Guarda (APG) criticou hoje as condições...

## Obama considera métodos de tortura da CIA "contrários aos valores" dos EUA

Ontem, 17:56 | Mundo | O Presidente Barack Obama denunciou hoje os métodos de tortura da CIA, agência...

## Relatório norte-americano qualifica interrogatórios da CIA como ineficazes e brutais

Ontem, 17:49 | Mundo | As técnicas de interrogatório usadas pela CIA a suspeitos de terrorismo após...

## Procurador-geral do Brasil diz que país "é extremamente corrupto"

Ontem, 17:47 | Mundo | O procurador-geral do Brasil, Rodrigo Janot, disse hoje que o seu país é "extremamente...

## Secretário-geral da ONU acredita que há ainda hipótese de limitar aquecimento global a nível seguro

Ontem, 17:45 | Mundo | O secretário-geral da ONU, Ban Ki-moon, disse hoje que ainda "há uma hipótese"...

## Bolsa de Lisboa fecha a perder 2,45% com todas as cotadas no vermelho

Ontem, 17:42 | Economia | A Bolsa de Lisboa fechou hoje no vermelho, em linha com as principais praças europeias,...

## Entregue petição com mais de 1 milhão de assinaturas contra acordo da UE com EUA

Ontem, 17:41 | Mundo | A plataforma que reúne mais de 320 grupos da sociedade civil contra um acordo de comércio...

## Unidade para Pessoas com perturbação mental aguda na Casa de Saúde S. João de Deus inaugurada sexta-feira

Ontem, 16:37 | Madeira | A Casa de Saúde S. João de Deus inaugura sexta-feira, às 17h00, a Unidade...

## Dossiers

- Natal 2014

  ## Câmara de Lobos com ‘mais brilho’ do que o Funchal

  DIÁRIO 2014-12-09 | Pelo menos para já, as iluminações decorativas na cidade de Câmara...

- Natal 2014

  ## ‘Função do porco’ reeditada na Camacha

  DIÁRIO 2014-12-09 | Tradição Numa altura em que está debaixo de críticas, a ‘Função...

- Natal 2014

  ## ‘Réveillon’ da ‘Caras’ traz Cuca Roseta

  DIÁRIO 2014-12-09 | A festa de ‘Réveillon’ da ‘Caras’ realiza-se noCAfé do Teatro

- Natal 2014

  ## Artistas juntos num espectáculo solidário

  DIÁRIO 2014-12-09 | O objectivo do evento na Ponta do Sol foi reunir ajuda às famílias desfavorecidas

- Natal 2014

  ## Bolo de mel gigante na Rua da Carreira

  DIÁRIO 2014-12-09 | A Junta de Freguesia de São Pedro realiza no dia 13, na Rua da Carreira, entre as 10 e as 18 horas,...

## Os mais...

- lidos
- comentados
- etiquetados

- ## Homem atirou-se da ponte sobre as fozes das ribeiras na Praça da Autonomia 42 comentários 22981

- ## Armazém do Mercado amanhã em pré-abertura 11 comentários 6078

- ## Chegada prevista entre as 16 e as 17 horas 4865

- ## TAP confirma suspensão da rota Funchal/Londres Funchal 6 comentários 4213

- ## Família madeirense percorre 1.300 quilómetros para ver maior presépio mecânico do Mundo 3 comentários 2799

- ## Nacional vence Marítimo por 3-0 66 comentários

- ## Homem atirou-se da ponte sobre as fozes das ribeiras na Praça da Autonomia 42 comentários

- ## Nivalda pergunta a Garcês se as obras são "só para a fotografia" 21 comentários

- ## Bispo do Funchal inaugurou monumento comemorativo dos 500 anos da Diocese 18 comentários

- ## 122 milhões de juros para pagar em 4 anos 13 comentários

ALM bes ricardo salgado Marítimo Liga dos Campeões ONU EUA Francisco Lufinha Benfica Kitesurf Nacional PS TAP China Cabo Verde Jogos Olímpicos UE Brasil ébola crime Estádio dos Barreiros MINI Kitesurf Odyssey UNICEF UMAR Vulcão Escola Corrupção Julgamento Pelé Real Madrid

PUBLICIDADE

## Espaço participação

### O que acha das iluminações de Natal deste ano no Funchal?

A inovação respeitou tradição? O que lhe agrada mais? E o que merece reparo

182 comentários

40

Os portugueses gastaram 40 euros em média nas compras realizadas em lojas, através dos terminais de pagamento automático da rede Multibanco, entre os dias 24 de novembro e 07 de dezembro, informa a Sibs.

A ausência de um orçamento condicionaria a vida dos madeirenses e afectaria a imagem da região.

Jaime Filipe Ramos, ALM, 9.12.2014

Siga-nos em...

PUBLICIDADE

### Foto-reportagens

30 fotos do dérbi que opôs Nacional e Marítimo

O jogo de segunda-feira terminou com uma vitória dos alvinegros por três bolas a zero

Camacha reedita 'Função do Porco' no feriado da Imaculada Conceição

Hoje à tarde, o porco chegou já morto ao centro da vila

104º aniversário do Nacional da Madeira

Clube fez festa, no domingo à noite, no Pestana Casino Park Hotel

Opinião
Espaço Opinião

## Bernardo Melvill Araujo

Visão e Liderança

Elevada capacidade para interpretar correctamente as situações e problemas, percepção...

Espaço Opinião

## Ricardo Miguel Oliveira

Poios da ilha (9)

É hora de abrir regos. Como é fácil as modas virarem tradição,...

Opinião

## José Manuel Oliveira

Dignidade

Temos vivido tempos extremamente difíceis que têm aprofundado as desigualdades...

Opinião

## Roberto Almada

O conforto das “meias-tintas”!

No encerramento do Congresso do PS, António Costa, o novo Secretário-Geral do partido...

PUBLICIDADE

## Madeira

## Unidade para Pessoas com perturbação mental aguda na Casa de Saúde S. João de Deus inaugurada sexta-feira

A Casa de Saúde S. João de Deus inaugura sexta-feira, às 17h00, a Unidade...

## Processo contra Alberto João Jardim com alegações finais a 19 de Dezembro

O Tribunal de Instância Local do Funchal agendou, hoje, para dia o 19 de dezembro as alegações... 2 comentários

## Associação de apoio à mulher UMAR abre amanhã sede regional

A associação União de Mulheres Alternativa e Resposta (UMAR) inaugura...

## Madeira é a região onde mais se morre por doenças respiratórias

Mortalidade por estas patologias corresponde a 18,5% da totalidade dos óbitos 4 comentários

ver todas »

## Política

O "melhor orçamento" porque é o último
PTP acusa a maioria de proteger a "nomenclatura do regime"
Liliana Rodrigues em encontro de preparação do Fórum das Regiões Ultraperiféricas
Presidente da Assembleia da Ribeira Brava aborda “conturbado processo” da obra da escola
Carlos Pereira lembra tudo o que afirmou e que agora é reconhecido

## Economia

Altice assina acordo definitivo com Oi para comprar PT Portugal
Ricciardi acusa Ricardo Salgado de "infâmia"
Bolsa de Lisboa fecha a perder 2,45% com todas as cotadas no vermelho
TAP confirma suspensão da rota Funchal/Londres Funchal
Portugueses estão a gastar 40 euros em média por compra com Multibanco

## País

Cavaco contesta que tenha influenciado compra de acções do BES
Sorteio de sexta-feira do Euromilhões com 'jackpot' de 31 milhões de euros
Pilotos da Portugália admitem fazer greve contra privatização do grupo TAP
Posto da GNR de Castanheira do Ribatejo com infiltrações de água e baratas
Cem pessoas detidas em 3 anos por corrupção, peculato e branqueamento de capitais

## Mundo

Obama considera métodos de tortura da CIA "contrários aos valores" dos EUA
Relatório norte-americano qualifica interrogatórios da CIA como ineficazes e brutais
Procurador-geral do Brasil diz que país "é extremamente corrupto"
Secretário-geral da ONU acredita que há ainda hipótese de limitar aquecimento global a nível seguro
Entregue petição com mais de 1 milhão de assinaturas contra acordo da UE com EUA

## 5 Sentidos

Manoel de Oliveira recebeu Legião de Honra francesa por "carreira fora do comum"
Por ano haverá um novo volume sobre a História da Madeira da autoria de Rui Carita
Teatral assinala 25 anos
Aniversário de Manoel de Oliveira no Museu de Imprensa
1º Volume da 'História da Madeira' apresentado hoje

## Desporto

Real Madrid volta a vencer todos os jogos e faz história na "Champions"
União e APD-M apresentaram projecto com o circo Luna Park
Leonardo Jardim estreia-se com passagem aos oitavos-de-final
Madeira SAD defronta Sporting na Taça de Portugal
Laurent Blanc propõe uma Bola de Ouro para Ronaldo e outra para Messi